const { request } = require('./request')
/**
 * 获取验证码
 * @param obj
 * @returns {Promise<unknown>}
 */
export const sendCode = (obj) => request({
  url: '/api/send/code',
  method: 'POST',
  data: {
    'phone': obj.phone, // 手机号码
    'type': obj.type // 1注册2登录3修改密码
  },
  showLoading: false
})

/**
 * 小程序手机号登录
 * @param obj
 * @returns {Promise<*>}
 */
export const miniPhoneLogin = (obj) => request({
  url: '/api/user/mini/phone/login',
  method: 'POST',
  data: {
    'code': obj.wxCode, // 小程序授权code
    'user_phone': obj.cellphone, // 手机号
    'user_code': obj.code // 验证码
  },
  showLoading: false
})

/**
 * 小程序原生登录
 * @param obj
 * @returns {Promise<*>}
 */
export const miniLogin = (obj) => request({
  url: '/api/user/mini/login',
  method: 'POST',
  data: {
    'code': obj.wxCode, // 小程序授权code
    'encryptedData': obj.encryptedData, // 加密数据
    'iv': obj.iv // iv
  }
})

/**
 * 获取用户信息
 * @returns {Promise<unknown>}
 */
export const getUserInfo = () => request({
  url: '/api/user/info',
  method: 'POST',
  showLoading: false
}, false)

/**
 * 更新用户信息
 * @param obj
 * @returns {Promise<unknown>}
 */
export const updateUserInfo = (obj) => request({
  url: '/api/user/update/info',
  method: 'POST',
  data: {
    // 'user_nickname': 'sd', // 用户昵称
    // 'user_head_img_url': 'sdsff', // 用户头像
    // 'user_sex': 1, // 性别(1男2女)
    // 'user_address': 'sdsdsdsugddug', // 地址
    ...obj
  },
  showLoading: true
})

/**
 * 用户退出登录接口
 * @returns {Promise<unknown>}
 */
export const userLoginOut = () => request({
  url: '/api/user/login/out',
  method: 'POST',
  showLoading: false
})
